@@ -860,7 +860,7 @@ htex_goback()
 		    extractbase(dvi_name);
 		} else {
 		    perror(dvi_name);
-		    cleanup_and_exit(1);
+		    exit(1);
 		}
 		htex_can_it();
 		htex_reinit();
@@ -1082,17 +1082,16 @@ char *cp;
 #ifdef HTEX
 #undef exit /* just in case */
 void
-cleanup_and_exit(arg)
+htex_cleanup(arg)
 int arg;
 {
 	/* Delete all the temp files we created */
 	for (;nURLs>0; nURLs--) {
-		unlink(filelist[nURLs-1].file);
+	  /* fprintf(stderr,"htex: Unlinking %s\n",filelist[nURLs-1].file); */
+	  unlink(filelist[nURLs-1].file);
 	}
-	if (temporary_dir) rmdir(temporary_dir);
 	HTCache_flushAll();
 	HTProfile_delete();
-	exit(arg);
 }
 
 /* Extract the URL base name from initial file name */
@@ -1149,6 +1148,8 @@ open_www_file()
 {
   char *url = NULL;
 
+  atexit(htex_cleanup);
+
   if (debug & DBG_HYPER) {
     fprintf(stderr, "open_www_file(%s)\n", dvi_name);
   }
@@ -1211,7 +1212,7 @@ open_www_file()
 	return 1;
       } else {
 	perror(dvi_name);
-	cleanup_and_exit(1);
+	exit(1);
       }
     }
   }
