@@ -138,7 +138,7 @@ char *HTAppName = "oxdvik";
 #else
 char *HTAppName = "xdvik";
 #endif
-char *HTAppVersion = VERSION;
+char *HTAppVersion = XDVIVERSION;
 #endif
 
 
@@ -686,6 +686,7 @@ static	_Xconst	char	*usagestr[] = {
 	/* [dummy] */		"z"
 };
 
+static char *TmpDir=NULL;
 
 #ifndef MOTIF
 
@@ -1802,13 +1803,30 @@ set_icon_and_title (dvi_name, icon_ret, title_ret, set_std)
   }
 }
 
+
+static void remove_temporary_dir(void)
+
+{
+  int err;
+
+  if (TmpDir!=NULL) {
+    err=rmdir(TmpDir);
+    if (err!=0 && errno!=ENOENT) {
+      char *buffer=malloc(160);
+      if (buffer==NULL) oops("Please buy more RAM");
+      sprintf(buffer,"xdvik: Warning: Could not remove temporary directory %s",
+	      TmpDir);
+      perror(buffer);
+    }
+  }
+}
+
 /* Create a temporary directory where we can write files from this program */
 static void
 make_temporary_dir(tmpdir)
 char **tmpdir;
 {
-  int ret, idval;
-  char * tmp;
+  int ret;
 
   *tmpdir = tempnam(NULL,"xdvi");
 
@@ -1820,6 +1838,15 @@ char **tmpdir;
 
   ret = mkdir(*tmpdir, 0700);
 
+  /* The use of atexit and one variable to store the directory name
+     makes this procedure a oneoff.  Enforce it */
+  if (TmpDir!=NULL)
+    oops("make_temporary_dir called twice!\n");
+
+  TmpDir=xstrdup(*tmpdir);
+
+  atexit(remove_temporary_dir);
+
   if (ret != 0)
     /* Didn't work, PANIC! */
     oops("Could not create temporary directory. Exiting.");
